@@ -122,11 +122,19 @@ extern "C" {
 #  define MRN_HAVE_HA_EXTRA_PREPARE_FOR_FORCED_CLOSE
 #endif
 
+#if (!defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 80002) ||   \
+  (defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100224)
+#  define MRN_HAVE_HA_EXTRA_BEGIN_ALTER_COPY
+#  define MRN_HAVE_HA_EXTRA_END_ALTER_COPY
+#endif
+
 #if (!defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 80002)
-#define MRN_HAVE_HA_EXTRA_SKIP_SERIALIZABLE_DD_VIEW
-#define MRN_HAVE_HA_EXTRA_BEGIN_ALTER_COPY
-#define MRN_HAVE_HA_EXTRA_END_ALTER_COPY
-#define MRN_HAVE_HA_EXTRA_NO_AUTOINC_LOCKING
+#  define MRN_HAVE_HA_EXTRA_SKIP_SERIALIZABLE_DD_VIEW
+#  define MRN_HAVE_HA_EXTRA_NO_AUTOINC_LOCKING
+#endif
+
+#if (defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100224)
+#  define MRN_HAVE_HA_EXTRA_FAKE_START_STMT
 #endif
 
 #if MYSQL_VERSION_ID >= 50607 && \
@@ -146,12 +154,6 @@ extern "C" {
 #  define MRN_HAVE_HA_EXTRA_STARTING_ORDERED_INDEX_SCAN
 #endif
 
-#if MYSQL_VERSION_ID >= 100306 && defined(MRN_MARIADB_P)
-#  define MRN_HAVE_HA_EXTRA_BEGIN_ALTER_COPY
-#  define MRN_HAVE_HA_EXTRA_END_ALTER_COPY
-#  define MRN_HAVE_HA_EXTRA_FAKE_START_STMT
-#endif
-
 #if MYSQL_VERSION_ID >= 50604 && !defined(MRN_MARIADB_P)
 #  define MRN_TIMESTAMP_USE_TIMEVAL
 #elif defined(MRN_MARIADB_P)
@@ -326,6 +328,10 @@ typedef uint mrn_alter_table_flags;
 
 #if MYSQL_VERSION_ID < 80011 || defined(MRN_MARIADB_P)
 #  define MRN_HANDLER_HAVE_TABLE_CACHE_TYPE
+#endif
+
+#if MYSQL_VERSION_ID < 50726 ||                         \
+  (defined(MRN_MARIADB_P) && MYSQL_VERSION_ID < 100315)
 #  define MRN_HANDLER_HAVE_REGISTER_QUERY_CACHE_TABLE
 #endif
 
@@ -409,6 +415,12 @@ typedef uint mrn_alter_table_flags;
 #  define MRN_HANDLER_HAVE_CAN_SWITCH_ENGINES
 #endif
 
+#if !defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 80016
+#  define MRN_HANDLER_COND_PUSH_HAVE_OTHER_TABLES_OK
+#else
+#  define MRN_HANDLER_HAVE_COND_POP
+#endif
+
 class ha_mroonga;
 
 /* structs */
@@ -660,8 +672,15 @@ public:
   FT_INFO *ft_init_ext(uint flags, uint inx, String *key);
   int ft_read(uchar *buf);
 
-  const Item *cond_push(const Item *cond);
-  void cond_pop();
+  const Item *cond_push(const Item *cond
+#ifdef MRN_HANDLER_COND_PUSH_HAVE_OTHER_TABLES_OK
+                        ,
+                        bool other_tables_ok
+#endif
+    ) mrn_override;
+#ifdef MRN_HANDLER_HAVE_COND_POP
+  void cond_pop() mrn_override;
+#endif
 
   int reset();
 
@@ -846,7 +865,7 @@ protected:
                                       char *table_key,
                                       uint key_length,
                                       qc_engine_callback *engine_callback,
-                                      ulonglong *engine_data);
+                                      ulonglong *engine_data) mrn_override;
 #endif
 #ifdef MRN_HANDLER_HAVE_CHECK_IF_SUPPORTED_INPLACE_ALTER
   bool prepare_inplace_alter_table(TABLE *altered_table,
@@ -1355,10 +1374,22 @@ private:
   FT_INFO *generic_ft_init_ext(uint flags, uint key_nr, String *key);
   int wrapper_ft_read(uchar *buf);
   int storage_ft_read(uchar *buf);
-  const Item *wrapper_cond_push(const Item *cond);
-  const Item *storage_cond_push(const Item *cond);
+  const Item *wrapper_cond_push(const Item *cond
+#ifdef MRN_HANDLER_COND_PUSH_HAVE_OTHER_TABLES_OK
+                                ,
+                                bool other_tables_ok
+#endif
+    );
+  const Item *storage_cond_push(const Item *cond
+#ifdef MRN_HANDLER_COND_PUSH_HAVE_OTHER_TABLES_OK
+                                ,
+                                bool other_tables_ok
+#endif
+    );
+#ifdef MRN_HANDLER_HAVE_COND_POP
   void wrapper_cond_pop();
   void storage_cond_pop();
+#endif
   handler *wrapper_clone(const char *name, MEM_ROOT *mem_root);
   handler *storage_clone(const char *name, MEM_ROOT *mem_root);
   void wrapper_print_error(int error, myf flag);
