@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2011-2018 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2011-2019 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -372,6 +372,11 @@ typedef HASH mrn_table_def_cache_type;
 #  define MRN_HAVE_SQL_DERROR_H
 #endif
 
+#if !defined(MRN_MARIADB_P) ||                                     \
+  (defined(MRN_MARIADB_P) && MYSQL_VERSION_ID >= 100000)
+#  define MRN_HAVE_MY_BYTEORDER_H
+#endif
+
 #if MYSQL_VERSION_ID >= 50706 && !defined(MRN_MARIADB_P)
 #  define MRN_HAVE_SPATIAL
 #elif defined(HAVE_SPATIAL)
@@ -763,3 +768,17 @@ typedef HASH mrn_table_def_cache_type;
 #  define mrn_alloc_table_share(table_list, key, key_length)    \
   alloc_table_share((table_list), (key), (key_length))
 #endif
+
+#if (MYSQL_VERSION_ID >= 80016 && !defined(MRN_MARIADB_P))
+#  define mrn_TIME_to_longlong_datetime_packed(mysql_time)      \
+  TIME_to_longlong_datetime_packed(mysql_time)
+#else
+#  define mrn_TIME_to_longlong_datetime_packed(mysql_time)      \
+  TIME_to_longlong_datetime_packed(&mysql_time)
+#endif
+
+#if (MYSQL_VERSION_ID >= 80016 && !defined(MRN_MARIADB_P))
+#  define MRN_STRING_APPEND append
+#else
+#  define MRN_STRING_APPEND q_append
+#endif
